# -----------------------------------------------------------------------------
# Copyright (c) Equinor ASA. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# -----------------------------------------------------------------------------

""" OSDU command line environment"""

# from pkgutil import extend_path
# __path__ = extend_path(__path__, __name__)

__VERSION__ = '0.0.7'
